BinaryNode

Enum BinaryNode 

pub enum BinaryNode {
    Atomic,
    Binary {
        lhs: Arc<BinaryNode>,
        rhs: Arc<BinaryNode>,
    },
}
A element in full binary tree Can be a atom or a node

Variants



Atomic

A atom in full binary tree



Binary

A node in full binary tree

Fields

lhs: Arc<BinaryNode>

left hand side leaf

rhs: Arc<BinaryNode>

right hand side leaf

Implementations

Source

impl BinaryNode

pub fn as_rpn(&self) -> ReversePolishNotation

Convert a full binary tree to reverse polish notation

Source

impl BinaryNode

pub fn as_expression<V, O>( &self, values: Vec<V>, actions: Vec<O>, ) -> Arc<ExpressionNode<V, O>>

Make the binary tree into an expression tree

Source

impl BinaryNode

pub fn atomic() -> Arc<Self>

Arguments
  • lhs:
  • rhs:

returns: Arc

pub fn binary(lhs: &Arc<Self>, rhs: &Arc<Self>) -> Arc<Self>

Arguments
  • lhs:
  • rhs:

returns: Arc

pub fn nodes(&self) -> usize

Count nodes in a full binary tree